@@ -1,5 +1,7 @@
 #!bin/sh
  
+# extract level names for translation
+$EXTRACTATTR --attr=board,name --attr=board,author levels/default.xml >> rc.cpp
 # invoke the extractrc script on all .ui, .rc, and .kcfg files in the sources
 # the results are stored in a pseudo .cpp file to be picked up by xgettext.
 $EXTRACTRC `find . -name \*.rc -o -name \*.ui -o -name \*.kcfg` >> rc.cpp
